# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'gui_design.ui'
#
# Created by: PyQt5 UI code generator 5.15.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(767, 740)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget.setObjectName("tabWidget")
        self.main = QtWidgets.QWidget()
        self.main.setObjectName("main")
        self.label_14 = QtWidgets.QLabel(self.main)
        self.label_14.setGeometry(QtCore.QRect(640, 220, 60, 16))
        self.label_14.setText("")
        self.label_14.setObjectName("label_14")
        self.layoutWidget = QtWidgets.QWidget(self.main)
        self.layoutWidget.setGeometry(QtCore.QRect(10, 10, 709, 476))
        self.layoutWidget.setObjectName("layoutWidget")
        self.horizontalLayout_32 = QtWidgets.QHBoxLayout(self.layoutWidget)
        self.horizontalLayout_32.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout_32.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_32.setSpacing(3)
        self.horizontalLayout_32.setObjectName("horizontalLayout_32")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.load_spectrum = QtWidgets.QPushButton(self.layoutWidget)
        self.load_spectrum.setObjectName("load_spectrum")
        self.horizontalLayout_2.addWidget(self.load_spectrum)
        self.load_new = QtWidgets.QCheckBox(self.layoutWidget)
        self.load_new.setObjectName("load_new")
        self.horizontalLayout_2.addWidget(self.load_new)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.line_13 = QtWidgets.QFrame(self.layoutWidget)
        self.line_13.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_13.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_13.setObjectName("line_13")
        self.verticalLayout.addWidget(self.line_13)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(self.layoutWidget)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.load_intensity = QtWidgets.QLineEdit(self.layoutWidget)
        self.load_intensity.setObjectName("load_intensity")
        self.gridLayout.addWidget(self.load_intensity, 2, 1, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.layoutWidget)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 2, 0, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.layoutWidget)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 3, 0, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.layoutWidget)
        self.label_5.setObjectName("label_5")
        self.gridLayout.addWidget(self.label_5, 4, 0, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.layoutWidget)
        self.label_6.setObjectName("label_6")
        self.gridLayout.addWidget(self.label_6, 5, 0, 1, 1)
        self.load_max_intens = QtWidgets.QLineEdit(self.layoutWidget)
        self.load_max_intens.setObjectName("load_max_intens")
        self.gridLayout.addWidget(self.load_max_intens, 4, 1, 1, 1)
        self.load_min_intens = QtWidgets.QLineEdit(self.layoutWidget)
        self.load_min_intens.setObjectName("load_min_intens")
        self.gridLayout.addWidget(self.load_min_intens, 3, 1, 1, 1)
        self.load_mz = QtWidgets.QLineEdit(self.layoutWidget)
        self.load_mz.setObjectName("load_mz")
        self.gridLayout.addWidget(self.load_mz, 1, 1, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.layoutWidget)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 1, 0, 1, 1)
        self.load_sep = QtWidgets.QLineEdit(self.layoutWidget)
        self.load_sep.setObjectName("load_sep")
        self.gridLayout.addWidget(self.load_sep, 0, 1, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.layoutWidget)
        self.label_7.setObjectName("label_7")
        self.gridLayout.addWidget(self.label_7, 6, 0, 1, 1)
        self.load_max_mz = QtWidgets.QLineEdit(self.layoutWidget)
        self.load_max_mz.setObjectName("load_max_mz")
        self.gridLayout.addWidget(self.load_max_mz, 6, 1, 1, 1)
        self.load_min_mz = QtWidgets.QLineEdit(self.layoutWidget)
        self.load_min_mz.setObjectName("load_min_mz")
        self.gridLayout.addWidget(self.load_min_mz, 5, 1, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout)
        self.line_11 = QtWidgets.QFrame(self.layoutWidget)
        self.line_11.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_11.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_11.setObjectName("line_11")
        self.verticalLayout.addWidget(self.line_11)
        self.save_spectrum = QtWidgets.QPushButton(self.layoutWidget)
        self.save_spectrum.setObjectName("save_spectrum")
        self.verticalLayout.addWidget(self.save_spectrum)
        self.print_spec = QtWidgets.QPushButton(self.layoutWidget)
        self.print_spec.setObjectName("print_spec")
        self.verticalLayout.addWidget(self.print_spec)
        self.line_12 = QtWidgets.QFrame(self.layoutWidget)
        self.line_12.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_12.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_12.setObjectName("line_12")
        self.verticalLayout.addWidget(self.line_12)
        self.plot_spectrum = QtWidgets.QPushButton(self.layoutWidget)
        self.plot_spectrum.setObjectName("plot_spectrum")
        self.verticalLayout.addWidget(self.plot_spectrum)
        self.plot_vk = QtWidgets.QPushButton(self.layoutWidget)
        self.plot_vk.setObjectName("plot_vk")
        self.verticalLayout.addWidget(self.plot_vk)
        self.horizontalLayout_32.addLayout(self.verticalLayout)
        self.line = QtWidgets.QFrame(self.layoutWidget)
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout_32.addWidget(self.line)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.assign = QtWidgets.QPushButton(self.layoutWidget)
        self.assign.setObjectName("assign")
        self.verticalLayout_3.addWidget(self.assign)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_10 = QtWidgets.QLabel(self.layoutWidget)
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_3.addWidget(self.label_10)
        self.assign_error_ppm = QtWidgets.QLineEdit(self.layoutWidget)
        self.assign_error_ppm.setObjectName("assign_error_ppm")
        self.horizontalLayout_3.addWidget(self.assign_error_ppm)
        self.mode = QtWidgets.QComboBox(self.layoutWidget)
        self.mode.setObjectName("mode")
        self.mode.addItem("")
        self.mode.addItem("")
        self.horizontalLayout_3.addWidget(self.mode)
        self.verticalLayout_3.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_22 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_22.setObjectName("horizontalLayout_22")
        self.show_assign_error = QtWidgets.QPushButton(self.layoutWidget)
        self.show_assign_error.setObjectName("show_assign_error")
        self.horizontalLayout_22.addWidget(self.show_assign_error)
        self.remove_C_13 = QtWidgets.QPushButton(self.layoutWidget)
        self.remove_C_13.setObjectName("remove_C_13")
        self.horizontalLayout_22.addWidget(self.remove_C_13)
        self.duplicates = QtWidgets.QPushButton(self.layoutWidget)
        self.duplicates.setObjectName("duplicates")
        self.horizontalLayout_22.addWidget(self.duplicates)
        self.verticalLayout_3.addLayout(self.horizontalLayout_22)
        self.line_9 = QtWidgets.QFrame(self.layoutWidget)
        self.line_9.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_9.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_9.setObjectName("line_9")
        self.verticalLayout_3.addWidget(self.line_9)
        self.listWidget_2 = QtWidgets.QListWidget(self.layoutWidget)
        self.listWidget_2.setObjectName("listWidget_2")
        self.verticalLayout_3.addWidget(self.listWidget_2)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_8 = QtWidgets.QLabel(self.layoutWidget)
        self.label_8.setObjectName("label_8")
        self.horizontalLayout.addWidget(self.label_8)
        self.assign_element = QtWidgets.QLineEdit(self.layoutWidget)
        self.assign_element.setObjectName("assign_element")
        self.horizontalLayout.addWidget(self.assign_element)
        self.label_9 = QtWidgets.QLabel(self.layoutWidget)
        self.label_9.setObjectName("label_9")
        self.horizontalLayout.addWidget(self.label_9)
        self.assign_isotope = QtWidgets.QLineEdit(self.layoutWidget)
        self.assign_isotope.setObjectName("assign_isotope")
        self.horizontalLayout.addWidget(self.assign_isotope)
        self.verticalLayout_3.addLayout(self.horizontalLayout)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_12 = QtWidgets.QLabel(self.layoutWidget)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout_4.addWidget(self.label_12)
        self.assign_range_min = QtWidgets.QLineEdit(self.layoutWidget)
        self.assign_range_min.setObjectName("assign_range_min")
        self.horizontalLayout_4.addWidget(self.assign_range_min)
        self.assign_range_max = QtWidgets.QLineEdit(self.layoutWidget)
        self.assign_range_max.setObjectName("assign_range_max")
        self.horizontalLayout_4.addWidget(self.assign_range_max)
        self.verticalLayout_3.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.add_element = QtWidgets.QPushButton(self.layoutWidget)
        self.add_element.setObjectName("add_element")
        self.horizontalLayout_5.addWidget(self.add_element)
        self.remove_element = QtWidgets.QPushButton(self.layoutWidget)
        self.remove_element.setObjectName("remove_element")
        self.horizontalLayout_5.addWidget(self.remove_element)
        self.reset_element = QtWidgets.QPushButton(self.layoutWidget)
        self.reset_element.setObjectName("reset_element")
        self.horizontalLayout_5.addWidget(self.reset_element)
        self.verticalLayout_3.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self.generate_gdf = QtWidgets.QPushButton(self.layoutWidget)
        self.generate_gdf.setObjectName("generate_gdf")
        self.horizontalLayout_19.addWidget(self.generate_gdf)
        self.rules = QtWidgets.QCheckBox(self.layoutWidget)
        self.rules.setObjectName("rules")
        self.horizontalLayout_19.addWidget(self.rules)
        self.verticalLayout_3.addLayout(self.horizontalLayout_19)
        self.line_10 = QtWidgets.QFrame(self.layoutWidget)
        self.line_10.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_10.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_10.setObjectName("line_10")
        self.verticalLayout_3.addWidget(self.line_10)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.gen_tmds = QtWidgets.QPushButton(self.layoutWidget)
        self.gen_tmds.setObjectName("gen_tmds")
        self.horizontalLayout_9.addWidget(self.gen_tmds)
        self.assign_tmds = QtWidgets.QPushButton(self.layoutWidget)
        self.assign_tmds.setObjectName("assign_tmds")
        self.horizontalLayout_9.addWidget(self.assign_tmds)
        self.verticalLayout_3.addLayout(self.horizontalLayout_9)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.label_13 = QtWidgets.QLabel(self.layoutWidget)
        self.label_13.setObjectName("label_13")
        self.horizontalLayout_6.addWidget(self.label_13)
        self.tmds_p = QtWidgets.QLineEdit(self.layoutWidget)
        self.tmds_p.setObjectName("tmds_p")
        self.horizontalLayout_6.addWidget(self.tmds_p)
        self.horizontalLayout_8.addLayout(self.horizontalLayout_6)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_16 = QtWidgets.QLabel(self.layoutWidget)
        self.label_16.setObjectName("label_16")
        self.horizontalLayout_7.addWidget(self.label_16)
        self.max_tmds = QtWidgets.QLineEdit(self.layoutWidget)
        self.max_tmds.setObjectName("max_tmds")
        self.horizontalLayout_7.addWidget(self.max_tmds)
        self.horizontalLayout_8.addLayout(self.horizontalLayout_7)
        self.tmds_c13 = QtWidgets.QCheckBox(self.layoutWidget)
        self.tmds_c13.setObjectName("tmds_c13")
        self.horizontalLayout_8.addWidget(self.tmds_c13)
        self.verticalLayout_3.addLayout(self.horizontalLayout_8)
        self.horizontalLayout_32.addLayout(self.verticalLayout_3)
        self.line_2 = QtWidgets.QFrame(self.layoutWidget)
        self.line_2.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.horizontalLayout_32.addWidget(self.line_2)
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.recallibrate = QtWidgets.QPushButton(self.layoutWidget)
        self.recallibrate.setObjectName("recallibrate")
        self.verticalLayout_5.addWidget(self.recallibrate)
        self.load_etalon = QtWidgets.QPushButton(self.layoutWidget)
        self.load_etalon.setObjectName("load_etalon")
        self.verticalLayout_5.addWidget(self.load_etalon)
        self.calc_recal_by_etalon = QtWidgets.QPushButton(self.layoutWidget)
        self.calc_recal_by_etalon.setObjectName("calc_recal_by_etalon")
        self.verticalLayout_5.addWidget(self.calc_recal_by_etalon)
        self.calc_self_recal_by_assign = QtWidgets.QPushButton(self.layoutWidget)
        self.calc_self_recal_by_assign.setObjectName("calc_self_recal_by_assign")
        self.verticalLayout_5.addWidget(self.calc_self_recal_by_assign)
        self.calc_self_recal_by_mdiff = QtWidgets.QPushButton(self.layoutWidget)
        self.calc_self_recal_by_mdiff.setObjectName("calc_self_recal_by_mdiff")
        self.verticalLayout_5.addWidget(self.calc_self_recal_by_mdiff)
        self.line_5 = QtWidgets.QFrame(self.layoutWidget)
        self.line_5.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_5.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_5.setObjectName("line_5")
        self.verticalLayout_5.addWidget(self.line_5)
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.load_error = QtWidgets.QPushButton(self.layoutWidget)
        self.load_error.setObjectName("load_error")
        self.horizontalLayout_11.addWidget(self.load_error)
        self.save_error = QtWidgets.QPushButton(self.layoutWidget)
        self.save_error.setObjectName("save_error")
        self.horizontalLayout_11.addWidget(self.save_error)
        self.verticalLayout_4.addLayout(self.horizontalLayout_11)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.show_error = QtWidgets.QPushButton(self.layoutWidget)
        self.show_error.setObjectName("show_error")
        self.horizontalLayout_10.addWidget(self.show_error)
        self.err_extra = QtWidgets.QPushButton(self.layoutWidget)
        self.err_extra.setObjectName("err_extra")
        self.horizontalLayout_10.addWidget(self.err_extra)
        self.verticalLayout_4.addLayout(self.horizontalLayout_10)
        self.verticalLayout_5.addLayout(self.verticalLayout_4)
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.range = QtWidgets.QPushButton(self.layoutWidget)
        self.range.setObjectName("range")
        self.horizontalLayout_12.addWidget(self.range)
        self.recal_range_min = QtWidgets.QLineEdit(self.layoutWidget)
        self.recal_range_min.setObjectName("recal_range_min")
        self.horizontalLayout_12.addWidget(self.recal_range_min)
        self.recal_range_max = QtWidgets.QLineEdit(self.layoutWidget)
        self.recal_range_max.setObjectName("recal_range_max")
        self.horizontalLayout_12.addWidget(self.recal_range_max)
        self.verticalLayout_5.addLayout(self.horizontalLayout_12)
        self.line_4 = QtWidgets.QFrame(self.layoutWidget)
        self.line_4.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_4.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_4.setObjectName("line_4")
        self.verticalLayout_5.addWidget(self.line_4)
        self.load_background = QtWidgets.QPushButton(self.layoutWidget)
        self.load_background.setObjectName("load_background")
        self.verticalLayout_5.addWidget(self.load_background)
        self.remove_background = QtWidgets.QPushButton(self.layoutWidget)
        self.remove_background.setObjectName("remove_background")
        self.verticalLayout_5.addWidget(self.remove_background)
        self.horizontalLayout_32.addLayout(self.verticalLayout_5)
        self.tabWidget.addTab(self.main, "")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.layoutWidget1 = QtWidgets.QWidget(self.tab)
        self.layoutWidget1.setGeometry(QtCore.QRect(10, 4, 725, 481))
        self.layoutWidget1.setObjectName("layoutWidget1")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.layoutWidget1)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout()
        self.verticalLayout_8.setSpacing(5)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setSpacing(4)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.multi_load = QtWidgets.QPushButton(self.layoutWidget1)
        self.multi_load.setObjectName("multi_load")
        self.horizontalLayout_15.addWidget(self.multi_load)
        self.add = QtWidgets.QPushButton(self.layoutWidget1)
        self.add.setObjectName("add")
        self.horizontalLayout_15.addWidget(self.add)
        self.verticalLayout_6.addLayout(self.horizontalLayout_15)
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.save_spectrum_2 = QtWidgets.QPushButton(self.layoutWidget1)
        self.save_spectrum_2.setObjectName("save_spectrum_2")
        self.horizontalLayout_16.addWidget(self.save_spectrum_2)
        self.remove = QtWidgets.QPushButton(self.layoutWidget1)
        self.remove.setObjectName("remove")
        self.horizontalLayout_16.addWidget(self.remove)
        self.verticalLayout_6.addLayout(self.horizontalLayout_16)
        self.line_19 = QtWidgets.QFrame(self.layoutWidget1)
        self.line_19.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_19.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_19.setObjectName("line_19")
        self.verticalLayout_6.addWidget(self.line_19)
        self.horizontalLayout_33 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_33.setObjectName("horizontalLayout_33")
        self.add_2 = QtWidgets.QPushButton(self.layoutWidget1)
        self.add_2.setObjectName("add_2")
        self.horizontalLayout_33.addWidget(self.add_2)
        self.sub = QtWidgets.QPushButton(self.layoutWidget1)
        self.sub.setObjectName("sub")
        self.horizontalLayout_33.addWidget(self.sub)
        self.and_ = QtWidgets.QPushButton(self.layoutWidget1)
        self.and_.setObjectName("and_")
        self.horizontalLayout_33.addWidget(self.and_)
        self.xor = QtWidgets.QPushButton(self.layoutWidget1)
        self.xor.setObjectName("xor")
        self.horizontalLayout_33.addWidget(self.xor)
        self.verticalLayout_6.addLayout(self.horizontalLayout_33)
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.int_sub = QtWidgets.QPushButton(self.layoutWidget1)
        self.int_sub.setObjectName("int_sub")
        self.horizontalLayout_18.addWidget(self.int_sub)
        self.venn = QtWidgets.QPushButton(self.layoutWidget1)
        self.venn.setObjectName("venn")
        self.horizontalLayout_18.addWidget(self.venn)
        self.verticalLayout_6.addLayout(self.horizontalLayout_18)
        self.line_3 = QtWidgets.QFrame(self.layoutWidget1)
        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.verticalLayout_6.addWidget(self.line_3)
        self.horizontalLayout_31 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_31.setObjectName("horizontalLayout_31")
        self.check_all = QtWidgets.QPushButton(self.layoutWidget1)
        self.check_all.setObjectName("check_all")
        self.horizontalLayout_31.addWidget(self.check_all)
        self.uncheck_all = QtWidgets.QPushButton(self.layoutWidget1)
        self.uncheck_all.setObjectName("uncheck_all")
        self.horizontalLayout_31.addWidget(self.uncheck_all)
        self.up = QtWidgets.QPushButton(self.layoutWidget1)
        self.up.setObjectName("up")
        self.horizontalLayout_31.addWidget(self.up)
        self.down = QtWidgets.QPushButton(self.layoutWidget1)
        self.down.setObjectName("down")
        self.horizontalLayout_31.addWidget(self.down)
        self.verticalLayout_6.addLayout(self.horizontalLayout_31)
        self.verticalLayout_8.addLayout(self.verticalLayout_6)
        self.listWidget = QtWidgets.QListWidget(self.layoutWidget1)
        self.listWidget.setObjectName("listWidget")
        self.verticalLayout_8.addWidget(self.listWidget)
        self.verticalLayout_8.setStretch(0, 1)
        self.verticalLayout_8.setStretch(1, 3)
        self.gridLayout_2.addLayout(self.verticalLayout_8, 0, 1, 1, 1)
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setSpacing(5)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.horizontalLayout_26 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_26.setObjectName("horizontalLayout_26")
        self.calc_all = QtWidgets.QPushButton(self.layoutWidget1)
        self.calc_all.setObjectName("calc_all")
        self.horizontalLayout_26.addWidget(self.calc_all)
        self.normalize = QtWidgets.QPushButton(self.layoutWidget1)
        self.normalize.setObjectName("normalize")
        self.horizontalLayout_26.addWidget(self.normalize)
        self.nomalize_box = QtWidgets.QComboBox(self.layoutWidget1)
        self.nomalize_box.setObjectName("nomalize_box")
        self.nomalize_box.addItem("")
        self.nomalize_box.addItem("")
        self.nomalize_box.addItem("")
        self.nomalize_box.addItem("")
        self.horizontalLayout_26.addWidget(self.nomalize_box)
        self.verticalLayout_7.addLayout(self.horizontalLayout_26)
        self.line_16 = QtWidgets.QFrame(self.layoutWidget1)
        self.line_16.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_16.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_16.setObjectName("line_16")
        self.verticalLayout_7.addWidget(self.line_16)
        self.horizontalLayout_25 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_25.setObjectName("horizontalLayout_25")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout()
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.count = QtWidgets.QPushButton(self.layoutWidget1)
        self.count.setObjectName("count")
        self.verticalLayout_9.addWidget(self.count)
        self.func = QtWidgets.QComboBox(self.layoutWidget1)
        self.func.setObjectName("func")
        self.func.addItem("")
        self.func.addItem("")
        self.func.addItem("")
        self.func.addItem("")
        self.func.addItem("")
        self.func.addItem("")
        self.verticalLayout_9.addWidget(self.func)
        self.horizontalLayout_25.addLayout(self.verticalLayout_9)
        self.verticalLayout_10 = QtWidgets.QVBoxLayout()
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.cut_box_2 = QtWidgets.QComboBox(self.layoutWidget1)
        self.cut_box_2.setObjectName("cut_box_2")
        self.cut_box_2.addItem("")
        self.cut_box_2.addItem("")
        self.cut_box_2.addItem("")
        self.verticalLayout_10.addWidget(self.cut_box_2)
        self.cut_box = QtWidgets.QComboBox(self.layoutWidget1)
        self.cut_box.setObjectName("cut_box")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.cut_box.addItem("")
        self.verticalLayout_10.addWidget(self.cut_box)
        self.horizontalLayout_25.addLayout(self.verticalLayout_10)
        self.cut_line = QtWidgets.QLineEdit(self.layoutWidget1)
        self.cut_line.setObjectName("cut_line")
        self.horizontalLayout_25.addWidget(self.cut_line)
        self.cut = QtWidgets.QPushButton(self.layoutWidget1)
        self.cut.setObjectName("cut")
        self.horizontalLayout_25.addWidget(self.cut)
        self.verticalLayout_7.addLayout(self.horizontalLayout_25)
        self.line_7 = QtWidgets.QFrame(self.layoutWidget1)
        self.line_7.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_7.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_7.setObjectName("line_7")
        self.verticalLayout_7.addWidget(self.line_7)
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.classes = QtWidgets.QPushButton(self.layoutWidget1)
        self.classes.setObjectName("classes")
        self.horizontalLayout_17.addWidget(self.classes)
        self.classes_choise = QtWidgets.QComboBox(self.layoutWidget1)
        self.classes_choise.setObjectName("classes_choise")
        self.classes_choise.addItem("")
        self.classes_choise.addItem("")
        self.classes_choise.addItem("")
        self.horizontalLayout_17.addWidget(self.classes_choise)
        self.line_17 = QtWidgets.QFrame(self.layoutWidget1)
        self.line_17.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_17.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_17.setObjectName("line_17")
        self.horizontalLayout_17.addWidget(self.line_17)
        self.plot_dbe = QtWidgets.QPushButton(self.layoutWidget1)
        self.plot_dbe.setObjectName("plot_dbe")
        self.horizontalLayout_17.addWidget(self.plot_dbe)
        self.label_18 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_18.setObjectName("label_18")
        self.horizontalLayout_17.addWidget(self.label_18)
        self.no_min = QtWidgets.QLineEdit(self.layoutWidget1)
        self.no_min.setObjectName("no_min")
        self.horizontalLayout_17.addWidget(self.no_min)
        self.no_max = QtWidgets.QLineEdit(self.layoutWidget1)
        self.no_max.setObjectName("no_max")
        self.horizontalLayout_17.addWidget(self.no_max)
        self.verticalLayout_7.addLayout(self.horizontalLayout_17)
        self.horizontalLayout_21 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_21.setObjectName("horizontalLayout_21")
        self.plot_matrix = QtWidgets.QPushButton(self.layoutWidget1)
        self.plot_matrix.setObjectName("plot_matrix")
        self.horizontalLayout_21.addWidget(self.plot_matrix)
        self.similarity_metric = QtWidgets.QComboBox(self.layoutWidget1)
        self.similarity_metric.setObjectName("similarity_metric")
        self.similarity_metric.addItem("")
        self.similarity_metric.addItem("")
        self.similarity_metric.addItem("")
        self.horizontalLayout_21.addWidget(self.similarity_metric)
        self.line_18 = QtWidgets.QFrame(self.layoutWidget1)
        self.line_18.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_18.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_18.setObjectName("line_18")
        self.horizontalLayout_21.addWidget(self.line_18)
        self.square_density_plot = QtWidgets.QPushButton(self.layoutWidget1)
        self.square_density_plot.setObjectName("square_density_plot")
        self.horizontalLayout_21.addWidget(self.square_density_plot)
        self.save_csv = QtWidgets.QPushButton(self.layoutWidget1)
        self.save_csv.setObjectName("save_csv")
        self.horizontalLayout_21.addWidget(self.save_csv)
        self.verticalLayout_7.addLayout(self.horizontalLayout_21)
        self.line_8 = QtWidgets.QFrame(self.layoutWidget1)
        self.line_8.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_8.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_8.setObjectName("line_8")
        self.verticalLayout_7.addWidget(self.line_8)
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        self.plot_spectrum_2 = QtWidgets.QPushButton(self.layoutWidget1)
        self.plot_spectrum_2.setObjectName("plot_spectrum_2")
        self.horizontalLayout_20.addWidget(self.plot_spectrum_2)
        self.line_15 = QtWidgets.QFrame(self.layoutWidget1)
        self.line_15.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_15.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_15.setObjectName("line_15")
        self.horizontalLayout_20.addWidget(self.line_15)
        self.label_23 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_23.setObjectName("label_23")
        self.horizontalLayout_20.addWidget(self.label_23)
        self.size_volume = QtWidgets.QLineEdit(self.layoutWidget1)
        self.size_volume.setObjectName("size_volume")
        self.horizontalLayout_20.addWidget(self.size_volume)
        self.label_11 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_11.setObjectName("label_11")
        self.horizontalLayout_20.addWidget(self.label_11)
        self.pow = QtWidgets.QLineEdit(self.layoutWidget1)
        self.pow.setObjectName("pow")
        self.horizontalLayout_20.addWidget(self.pow)
        self.verticalLayout_7.addLayout(self.horizontalLayout_20)
        self.horizontalLayout_28 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_28.setObjectName("horizontalLayout_28")
        self.scatter = QtWidgets.QPushButton(self.layoutWidget1)
        self.scatter.setObjectName("scatter")
        self.horizontalLayout_28.addWidget(self.scatter)
        self.scatter_box_1 = QtWidgets.QComboBox(self.layoutWidget1)
        self.scatter_box_1.setObjectName("scatter_box_1")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.scatter_box_1.addItem("")
        self.horizontalLayout_28.addWidget(self.scatter_box_1)
        self.sactter_box_2 = QtWidgets.QComboBox(self.layoutWidget1)
        self.sactter_box_2.setObjectName("sactter_box_2")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.sactter_box_2.addItem("")
        self.horizontalLayout_28.addWidget(self.sactter_box_2)
        self.sactter_box_3 = QtWidgets.QComboBox(self.layoutWidget1)
        self.sactter_box_3.setObjectName("sactter_box_3")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.sactter_box_3.addItem("")
        self.horizontalLayout_28.addWidget(self.sactter_box_3)
        self.verticalLayout_7.addLayout(self.horizontalLayout_28)
        self.horizontalLayout_29 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_29.setObjectName("horizontalLayout_29")
        self.density_plot = QtWidgets.QPushButton(self.layoutWidget1)
        self.density_plot.setObjectName("density_plot")
        self.horizontalLayout_29.addWidget(self.density_plot)
        self.density = QtWidgets.QPushButton(self.layoutWidget1)
        self.density.setObjectName("density")
        self.horizontalLayout_29.addWidget(self.density)
        self.density_box = QtWidgets.QComboBox(self.layoutWidget1)
        self.density_box.setObjectName("density_box")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.density_box.addItem("")
        self.horizontalLayout_29.addWidget(self.density_box)
        self.verticalLayout_7.addLayout(self.horizontalLayout_29)
        self.line_14 = QtWidgets.QFrame(self.layoutWidget1)
        self.line_14.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_14.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_14.setObjectName("line_14")
        self.verticalLayout_7.addWidget(self.line_14)
        self.line_6 = QtWidgets.QFrame(self.layoutWidget1)
        self.line_6.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_6.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_6.setObjectName("line_6")
        self.verticalLayout_7.addWidget(self.line_6)
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.label_24 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_24.setObjectName("label_24")
        self.horizontalLayout_14.addWidget(self.label_24)
        self.x1 = QtWidgets.QLineEdit(self.layoutWidget1)
        self.x1.setObjectName("x1")
        self.horizontalLayout_14.addWidget(self.x1)
        self.label_17 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_17.setObjectName("label_17")
        self.horizontalLayout_14.addWidget(self.label_17)
        self.x2 = QtWidgets.QLineEdit(self.layoutWidget1)
        self.x2.setObjectName("x2")
        self.horizontalLayout_14.addWidget(self.x2)
        self.label_25 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_25.setObjectName("label_25")
        self.horizontalLayout_14.addWidget(self.label_25)
        self.y1 = QtWidgets.QLineEdit(self.layoutWidget1)
        self.y1.setObjectName("y1")
        self.horizontalLayout_14.addWidget(self.y1)
        self.label_26 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_26.setObjectName("label_26")
        self.horizontalLayout_14.addWidget(self.label_26)
        self.y2 = QtWidgets.QLineEdit(self.layoutWidget1)
        self.y2.setObjectName("y2")
        self.horizontalLayout_14.addWidget(self.y2)
        self.verticalLayout_7.addLayout(self.horizontalLayout_14)
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.label_15 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_15.setObjectName("label_15")
        self.horizontalLayout_13.addWidget(self.label_15)
        self.dpi_line = QtWidgets.QLineEdit(self.layoutWidget1)
        self.dpi_line.setObjectName("dpi_line")
        self.horizontalLayout_13.addWidget(self.dpi_line)
        self.label_21 = QtWidgets.QLabel(self.layoutWidget1)
        self.label_21.setObjectName("label_21")
        self.horizontalLayout_13.addWidget(self.label_21)
        self.size_line = QtWidgets.QLineEdit(self.layoutWidget1)
        self.size_line.setObjectName("size_line")
        self.horizontalLayout_13.addWidget(self.size_line)
        self.size_line_2 = QtWidgets.QLineEdit(self.layoutWidget1)
        self.size_line_2.setObjectName("size_line_2")
        self.horizontalLayout_13.addWidget(self.size_line_2)
        self.verticalLayout_7.addLayout(self.horizontalLayout_13)
        self.horizontalLayout_27 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_27.setObjectName("horizontalLayout_27")
        self.path = QtWidgets.QPushButton(self.layoutWidget1)
        self.path.setObjectName("path")
        self.horizontalLayout_27.addWidget(self.path)
        self.format = QtWidgets.QComboBox(self.layoutWidget1)
        self.format.setObjectName("format")
        self.format.addItem("")
        self.format.addItem("")
        self.format.addItem("")
        self.format.addItem("")
        self.horizontalLayout_27.addWidget(self.format)
        self.save_box = QtWidgets.QCheckBox(self.layoutWidget1)
        self.save_box.setObjectName("save_box")
        self.horizontalLayout_27.addWidget(self.save_box)
        self.verticalLayout_7.addLayout(self.horizontalLayout_27)
        self.gridLayout_2.addLayout(self.verticalLayout_7, 0, 2, 1, 1)
        self.tabWidget.addTab(self.tab, "")
        self.verticalLayout_2.addWidget(self.tabWidget)
        self.textBrowser = QtWidgets.QTextBrowser(self.centralwidget)
        self.textBrowser.setObjectName("textBrowser")
        self.verticalLayout_2.addWidget(self.textBrowser)
        self.verticalLayout_2.setStretch(0, 3)
        self.verticalLayout_2.setStretch(1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.tabWidget, self.load_spectrum)
        MainWindow.setTabOrder(self.load_spectrum, self.load_new)
        MainWindow.setTabOrder(self.load_new, self.load_sep)
        MainWindow.setTabOrder(self.load_sep, self.load_mz)
        MainWindow.setTabOrder(self.load_mz, self.load_intensity)
        MainWindow.setTabOrder(self.load_intensity, self.load_min_intens)
        MainWindow.setTabOrder(self.load_min_intens, self.load_max_intens)
        MainWindow.setTabOrder(self.load_max_intens, self.load_min_mz)
        MainWindow.setTabOrder(self.load_min_mz, self.load_max_mz)
        MainWindow.setTabOrder(self.load_max_mz, self.save_spectrum)
        MainWindow.setTabOrder(self.save_spectrum, self.print_spec)
        MainWindow.setTabOrder(self.print_spec, self.plot_spectrum)
        MainWindow.setTabOrder(self.plot_spectrum, self.plot_vk)
        MainWindow.setTabOrder(self.plot_vk, self.assign)
        MainWindow.setTabOrder(self.assign, self.assign_error_ppm)
        MainWindow.setTabOrder(self.assign_error_ppm, self.mode)
        MainWindow.setTabOrder(self.mode, self.show_assign_error)
        MainWindow.setTabOrder(self.show_assign_error, self.remove_C_13)
        MainWindow.setTabOrder(self.remove_C_13, self.duplicates)
        MainWindow.setTabOrder(self.duplicates, self.listWidget_2)
        MainWindow.setTabOrder(self.listWidget_2, self.assign_element)
        MainWindow.setTabOrder(self.assign_element, self.assign_isotope)
        MainWindow.setTabOrder(self.assign_isotope, self.assign_range_min)
        MainWindow.setTabOrder(self.assign_range_min, self.assign_range_max)
        MainWindow.setTabOrder(self.assign_range_max, self.add_element)
        MainWindow.setTabOrder(self.add_element, self.remove_element)
        MainWindow.setTabOrder(self.remove_element, self.reset_element)
        MainWindow.setTabOrder(self.reset_element, self.generate_gdf)
        MainWindow.setTabOrder(self.generate_gdf, self.rules)
        MainWindow.setTabOrder(self.rules, self.gen_tmds)
        MainWindow.setTabOrder(self.gen_tmds, self.assign_tmds)
        MainWindow.setTabOrder(self.assign_tmds, self.tmds_p)
        MainWindow.setTabOrder(self.tmds_p, self.max_tmds)
        MainWindow.setTabOrder(self.max_tmds, self.tmds_c13)
        MainWindow.setTabOrder(self.tmds_c13, self.recallibrate)
        MainWindow.setTabOrder(self.recallibrate, self.load_etalon)
        MainWindow.setTabOrder(self.load_etalon, self.calc_recal_by_etalon)
        MainWindow.setTabOrder(self.calc_recal_by_etalon, self.calc_self_recal_by_assign)
        MainWindow.setTabOrder(self.calc_self_recal_by_assign, self.calc_self_recal_by_mdiff)
        MainWindow.setTabOrder(self.calc_self_recal_by_mdiff, self.load_error)
        MainWindow.setTabOrder(self.load_error, self.save_error)
        MainWindow.setTabOrder(self.save_error, self.show_error)
        MainWindow.setTabOrder(self.show_error, self.err_extra)
        MainWindow.setTabOrder(self.err_extra, self.range)
        MainWindow.setTabOrder(self.range, self.recal_range_min)
        MainWindow.setTabOrder(self.recal_range_min, self.recal_range_max)
        MainWindow.setTabOrder(self.recal_range_max, self.load_background)
        MainWindow.setTabOrder(self.load_background, self.remove_background)
        MainWindow.setTabOrder(self.remove_background, self.multi_load)
        MainWindow.setTabOrder(self.multi_load, self.add)
        MainWindow.setTabOrder(self.add, self.save_spectrum_2)
        MainWindow.setTabOrder(self.save_spectrum_2, self.remove)
        MainWindow.setTabOrder(self.remove, self.add_2)
        MainWindow.setTabOrder(self.add_2, self.sub)
        MainWindow.setTabOrder(self.sub, self.and_)
        MainWindow.setTabOrder(self.and_, self.xor)
        MainWindow.setTabOrder(self.xor, self.int_sub)
        MainWindow.setTabOrder(self.int_sub, self.venn)
        MainWindow.setTabOrder(self.venn, self.check_all)
        MainWindow.setTabOrder(self.check_all, self.uncheck_all)
        MainWindow.setTabOrder(self.uncheck_all, self.up)
        MainWindow.setTabOrder(self.up, self.down)
        MainWindow.setTabOrder(self.down, self.listWidget)
        MainWindow.setTabOrder(self.listWidget, self.calc_all)
        MainWindow.setTabOrder(self.calc_all, self.normalize)
        MainWindow.setTabOrder(self.normalize, self.nomalize_box)
        MainWindow.setTabOrder(self.nomalize_box, self.count)
        MainWindow.setTabOrder(self.count, self.cut_box_2)
        MainWindow.setTabOrder(self.cut_box_2, self.func)
        MainWindow.setTabOrder(self.func, self.cut_box)
        MainWindow.setTabOrder(self.cut_box, self.cut_line)
        MainWindow.setTabOrder(self.cut_line, self.cut)
        MainWindow.setTabOrder(self.cut, self.classes)
        MainWindow.setTabOrder(self.classes, self.classes_choise)
        MainWindow.setTabOrder(self.classes_choise, self.plot_dbe)
        MainWindow.setTabOrder(self.plot_dbe, self.no_min)
        MainWindow.setTabOrder(self.no_min, self.no_max)
        MainWindow.setTabOrder(self.no_max, self.plot_matrix)
        MainWindow.setTabOrder(self.plot_matrix, self.similarity_metric)
        MainWindow.setTabOrder(self.similarity_metric, self.square_density_plot)
        MainWindow.setTabOrder(self.square_density_plot, self.save_csv)
        MainWindow.setTabOrder(self.save_csv, self.plot_spectrum_2)
        MainWindow.setTabOrder(self.plot_spectrum_2, self.size_volume)
        MainWindow.setTabOrder(self.size_volume, self.pow)
        MainWindow.setTabOrder(self.pow, self.scatter)
        MainWindow.setTabOrder(self.scatter, self.scatter_box_1)
        MainWindow.setTabOrder(self.scatter_box_1, self.sactter_box_2)
        MainWindow.setTabOrder(self.sactter_box_2, self.sactter_box_3)
        MainWindow.setTabOrder(self.sactter_box_3, self.density_plot)
        MainWindow.setTabOrder(self.density_plot, self.density)
        MainWindow.setTabOrder(self.density, self.density_box)
        MainWindow.setTabOrder(self.density_box, self.x1)
        MainWindow.setTabOrder(self.x1, self.x2)
        MainWindow.setTabOrder(self.x2, self.y1)
        MainWindow.setTabOrder(self.y1, self.y2)
        MainWindow.setTabOrder(self.y2, self.dpi_line)
        MainWindow.setTabOrder(self.dpi_line, self.size_line)
        MainWindow.setTabOrder(self.size_line, self.size_line_2)
        MainWindow.setTabOrder(self.size_line_2, self.path)
        MainWindow.setTabOrder(self.path, self.format)
        MainWindow.setTabOrder(self.format, self.save_box)
        MainWindow.setTabOrder(self.save_box, self.textBrowser)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "nomspectra"))
        self.load_spectrum.setText(_translate("MainWindow", "Load Spectrum"))
        self.load_new.setText(_translate("MainWindow", "New"))
        self.label.setText(_translate("MainWindow", "Separator"))
        self.label_3.setText(_translate("MainWindow", "Intensity"))
        self.label_4.setText(_translate("MainWindow", "min Intens"))
        self.label_5.setText(_translate("MainWindow", "max Intens"))
        self.label_6.setText(_translate("MainWindow", "min m/z"))
        self.label_2.setText(_translate("MainWindow", "m/z"))
        self.label_7.setText(_translate("MainWindow", "max m/z"))
        self.save_spectrum.setText(_translate("MainWindow", "Save Spectrum"))
        self.print_spec.setText(_translate("MainWindow", "Print spectrum"))
        self.plot_spectrum.setText(_translate("MainWindow", "Plot Spectrum"))
        self.plot_vk.setText(_translate("MainWindow", "Plot Van Krevelin"))
        self.assign.setText(_translate("MainWindow", "Assign"))
        self.label_10.setText(_translate("MainWindow", "Err ppm"))
        self.mode.setItemText(0, _translate("MainWindow", "negative"))
        self.mode.setItemText(1, _translate("MainWindow", "positive"))
        self.show_assign_error.setText(_translate("MainWindow", "ShowErr"))
        self.remove_C_13.setText(_translate("MainWindow", "C_13"))
        self.duplicates.setText(_translate("MainWindow", "Dupl"))
        self.label_8.setText(_translate("MainWindow", "Element"))
        self.label_9.setText(_translate("MainWindow", "Isotope"))
        self.label_12.setText(_translate("MainWindow", "Range"))
        self.add_element.setText(_translate("MainWindow", "Add"))
        self.remove_element.setText(_translate("MainWindow", "Remove"))
        self.reset_element.setText(_translate("MainWindow", "Reset"))
        self.generate_gdf.setText(_translate("MainWindow", "Gen"))
        self.rules.setText(_translate("MainWindow", "Rules"))
        self.gen_tmds.setText(_translate("MainWindow", "Gen TMDS"))
        self.assign_tmds.setText(_translate("MainWindow", "Assign TMDS"))
        self.label_13.setText(_translate("MainWindow", "P"))
        self.label_16.setText(_translate("MainWindow", "N"))
        self.tmds_c13.setText(_translate("MainWindow", "C_13"))
        self.recallibrate.setText(_translate("MainWindow", "Recallibrate"))
        self.load_etalon.setText(_translate("MainWindow", "Load Etalon"))
        self.calc_recal_by_etalon.setText(_translate("MainWindow", "Calc Recal by Etalon"))
        self.calc_self_recal_by_assign.setText(_translate("MainWindow", "Calc Recal by Assign"))
        self.calc_self_recal_by_mdiff.setText(_translate("MainWindow", "Calc Recal by MDiff"))
        self.load_error.setText(_translate("MainWindow", "Load Error"))
        self.save_error.setText(_translate("MainWindow", "Save Error"))
        self.show_error.setText(_translate("MainWindow", "Show Error"))
        self.err_extra.setText(_translate("MainWindow", "Extrapolate"))
        self.range.setText(_translate("MainWindow", "Range"))
        self.load_background.setText(_translate("MainWindow", "Load Background"))
        self.remove_background.setText(_translate("MainWindow", "Remove Background"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.main), _translate("MainWindow", "treatment"))
        self.multi_load.setText(_translate("MainWindow", "Multi Load"))
        self.add.setText(_translate("MainWindow", "Add_Bufer"))
        self.save_spectrum_2.setText(_translate("MainWindow", "Save"))
        self.remove.setText(_translate("MainWindow", "Remove"))
        self.add_2.setText(_translate("MainWindow", "add"))
        self.sub.setText(_translate("MainWindow", "sub"))
        self.and_.setText(_translate("MainWindow", "and"))
        self.xor.setText(_translate("MainWindow", "xor"))
        self.int_sub.setText(_translate("MainWindow", "int_sub"))
        self.venn.setText(_translate("MainWindow", "venn"))
        self.check_all.setText(_translate("MainWindow", "all"))
        self.uncheck_all.setText(_translate("MainWindow", "none"))
        self.up.setText(_translate("MainWindow", "↑"))
        self.down.setText(_translate("MainWindow", "↓"))
        self.calc_all.setText(_translate("MainWindow", "Calculate"))
        self.normalize.setText(_translate("MainWindow", "Normalize"))
        self.nomalize_box.setItemText(0, _translate("MainWindow", "sum"))
        self.nomalize_box.setItemText(1, _translate("MainWindow", "max"))
        self.nomalize_box.setItemText(2, _translate("MainWindow", "mean"))
        self.nomalize_box.setItemText(3, _translate("MainWindow", "median"))
        self.count.setText(_translate("MainWindow", "Count"))
        self.func.setItemText(0, _translate("MainWindow", "weight"))
        self.func.setItemText(1, _translate("MainWindow", "mean"))
        self.func.setItemText(2, _translate("MainWindow", "median"))
        self.func.setItemText(3, _translate("MainWindow", "max"))
        self.func.setItemText(4, _translate("MainWindow", "min"))
        self.func.setItemText(5, _translate("MainWindow", "std"))
        self.cut_box_2.setItemText(0, _translate("MainWindow", ">"))
        self.cut_box_2.setItemText(1, _translate("MainWindow", "<"))
        self.cut_box_2.setItemText(2, _translate("MainWindow", "="))
        self.cut_box.setItemText(0, _translate("MainWindow", "intensity"))
        self.cut_box.setItemText(1, _translate("MainWindow", "mass"))
        self.cut_box.setItemText(2, _translate("MainWindow", "Ke"))
        self.cut_box.setItemText(3, _translate("MainWindow", "KMD"))
        self.cut_box.setItemText(4, _translate("MainWindow", "C"))
        self.cut_box.setItemText(5, _translate("MainWindow", "H"))
        self.cut_box.setItemText(6, _translate("MainWindow", "O"))
        self.cut_box.setItemText(7, _translate("MainWindow", "N"))
        self.cut_box.setItemText(8, _translate("MainWindow", "S"))
        self.cut_box.setItemText(9, _translate("MainWindow", "H/C"))
        self.cut_box.setItemText(10, _translate("MainWindow", "O/C"))
        self.cut_box.setItemText(11, _translate("MainWindow", "AI"))
        self.cut_box.setItemText(12, _translate("MainWindow", "CAI"))
        self.cut_box.setItemText(13, _translate("MainWindow", "DBE"))
        self.cut_box.setItemText(14, _translate("MainWindow", "DBE_AI"))
        self.cut_box.setItemText(15, _translate("MainWindow", "DBE-O"))
        self.cut_box.setItemText(16, _translate("MainWindow", "DBE-OC"))
        self.cut_box.setItemText(17, _translate("MainWindow", "CRAM"))
        self.cut_box.setItemText(18, _translate("MainWindow", "NOSC"))
        self.cut.setText(_translate("MainWindow", "Cut"))
        self.classes.setText(_translate("MainWindow", "Classes"))
        self.classes_choise.setItemText(0, _translate("MainWindow", "laszakovits"))
        self.classes_choise.setItemText(1, _translate("MainWindow", "kellerman"))
        self.classes_choise.setItemText(2, _translate("MainWindow", "perminova"))
        self.plot_dbe.setText(_translate("MainWindow", "DBE vs nO"))
        self.label_18.setText(_translate("MainWindow", "nO"))
        self.plot_matrix.setText(_translate("MainWindow", "Simmilarity"))
        self.similarity_metric.setItemText(0, _translate("MainWindow", "tanimoto"))
        self.similarity_metric.setItemText(1, _translate("MainWindow", "jaccard"))
        self.similarity_metric.setItemText(2, _translate("MainWindow", "cosine"))
        self.square_density_plot.setText(_translate("MainWindow", "Squares"))
        self.save_csv.setText(_translate("MainWindow", "SaveCSV"))
        self.plot_spectrum_2.setText(_translate("MainWindow", "Spectrum"))
        self.label_23.setText(_translate("MainWindow", "Size"))
        self.label_11.setText(_translate("MainWindow", "Pow"))
        self.scatter.setText(_translate("MainWindow", "Scatter"))
        self.scatter_box_1.setItemText(0, _translate("MainWindow", "O/C"))
        self.scatter_box_1.setItemText(1, _translate("MainWindow", "H/C"))
        self.scatter_box_1.setItemText(2, _translate("MainWindow", "Ke"))
        self.scatter_box_1.setItemText(3, _translate("MainWindow", "KMD"))
        self.scatter_box_1.setItemText(4, _translate("MainWindow", "intensity"))
        self.scatter_box_1.setItemText(5, _translate("MainWindow", "mass"))
        self.scatter_box_1.setItemText(6, _translate("MainWindow", "C"))
        self.scatter_box_1.setItemText(7, _translate("MainWindow", "H"))
        self.scatter_box_1.setItemText(8, _translate("MainWindow", "O"))
        self.scatter_box_1.setItemText(9, _translate("MainWindow", "N"))
        self.scatter_box_1.setItemText(10, _translate("MainWindow", "S"))
        self.scatter_box_1.setItemText(11, _translate("MainWindow", "CAI"))
        self.scatter_box_1.setItemText(12, _translate("MainWindow", "AI"))
        self.scatter_box_1.setItemText(13, _translate("MainWindow", "DBE"))
        self.scatter_box_1.setItemText(14, _translate("MainWindow", "DBE_AI"))
        self.scatter_box_1.setItemText(15, _translate("MainWindow", "DBE-O"))
        self.scatter_box_1.setItemText(16, _translate("MainWindow", "DBE-OC"))
        self.scatter_box_1.setItemText(17, _translate("MainWindow", "NOSC"))
        self.sactter_box_2.setItemText(0, _translate("MainWindow", "H/C"))
        self.sactter_box_2.setItemText(1, _translate("MainWindow", "O/C"))
        self.sactter_box_2.setItemText(2, _translate("MainWindow", "KMD"))
        self.sactter_box_2.setItemText(3, _translate("MainWindow", "Ke"))
        self.sactter_box_2.setItemText(4, _translate("MainWindow", "NOSC"))
        self.sactter_box_2.setItemText(5, _translate("MainWindow", "intensity"))
        self.sactter_box_2.setItemText(6, _translate("MainWindow", "mass"))
        self.sactter_box_2.setItemText(7, _translate("MainWindow", "C"))
        self.sactter_box_2.setItemText(8, _translate("MainWindow", "H"))
        self.sactter_box_2.setItemText(9, _translate("MainWindow", "O"))
        self.sactter_box_2.setItemText(10, _translate("MainWindow", "N"))
        self.sactter_box_2.setItemText(11, _translate("MainWindow", "S"))
        self.sactter_box_2.setItemText(12, _translate("MainWindow", "CAI"))
        self.sactter_box_2.setItemText(13, _translate("MainWindow", "AI"))
        self.sactter_box_2.setItemText(14, _translate("MainWindow", "DBE"))
        self.sactter_box_2.setItemText(15, _translate("MainWindow", "DBE_AI"))
        self.sactter_box_2.setItemText(16, _translate("MainWindow", "DBE-O"))
        self.sactter_box_2.setItemText(17, _translate("MainWindow", "DBE-OC"))
        self.sactter_box_3.setItemText(0, _translate("MainWindow", "intensity"))
        self.sactter_box_3.setItemText(1, _translate("MainWindow", "None"))
        self.sactter_box_3.setItemText(2, _translate("MainWindow", "Ke"))
        self.sactter_box_3.setItemText(3, _translate("MainWindow", "KMD"))
        self.sactter_box_3.setItemText(4, _translate("MainWindow", "mass"))
        self.sactter_box_3.setItemText(5, _translate("MainWindow", "NOSC"))
        self.sactter_box_3.setItemText(6, _translate("MainWindow", "C"))
        self.sactter_box_3.setItemText(7, _translate("MainWindow", "H"))
        self.sactter_box_3.setItemText(8, _translate("MainWindow", "O"))
        self.sactter_box_3.setItemText(9, _translate("MainWindow", "N"))
        self.sactter_box_3.setItemText(10, _translate("MainWindow", "S"))
        self.sactter_box_3.setItemText(11, _translate("MainWindow", "H/C"))
        self.sactter_box_3.setItemText(12, _translate("MainWindow", "O/C"))
        self.sactter_box_3.setItemText(13, _translate("MainWindow", "CAI"))
        self.sactter_box_3.setItemText(14, _translate("MainWindow", "AI"))
        self.sactter_box_3.setItemText(15, _translate("MainWindow", "DBE"))
        self.sactter_box_3.setItemText(16, _translate("MainWindow", "DBE_AI"))
        self.sactter_box_3.setItemText(17, _translate("MainWindow", "DBE-O"))
        self.sactter_box_3.setItemText(18, _translate("MainWindow", "DBE-OC"))
        self.density_plot.setText(_translate("MainWindow", "ScatterDens"))
        self.density.setText(_translate("MainWindow", "Density"))
        self.density_box.setItemText(0, _translate("MainWindow", "NOSC"))
        self.density_box.setItemText(1, _translate("MainWindow", "O/C"))
        self.density_box.setItemText(2, _translate("MainWindow", "H/C"))
        self.density_box.setItemText(3, _translate("MainWindow", "Ke"))
        self.density_box.setItemText(4, _translate("MainWindow", "KMD"))
        self.density_box.setItemText(5, _translate("MainWindow", "intensity"))
        self.density_box.setItemText(6, _translate("MainWindow", "mass"))
        self.density_box.setItemText(7, _translate("MainWindow", "C"))
        self.density_box.setItemText(8, _translate("MainWindow", "H"))
        self.density_box.setItemText(9, _translate("MainWindow", "O"))
        self.density_box.setItemText(10, _translate("MainWindow", "N"))
        self.density_box.setItemText(11, _translate("MainWindow", "S"))
        self.density_box.setItemText(12, _translate("MainWindow", "CAI"))
        self.density_box.setItemText(13, _translate("MainWindow", "AI"))
        self.density_box.setItemText(14, _translate("MainWindow", "DBE"))
        self.density_box.setItemText(15, _translate("MainWindow", "DBE_AI"))
        self.density_box.setItemText(16, _translate("MainWindow", "DBE-O"))
        self.density_box.setItemText(17, _translate("MainWindow", "DBE-OC"))
        self.label_24.setText(_translate("MainWindow", "x1"))
        self.label_17.setText(_translate("MainWindow", "x2"))
        self.label_25.setText(_translate("MainWindow", "y1"))
        self.label_26.setText(_translate("MainWindow", "y2"))
        self.label_15.setText(_translate("MainWindow", "dpi"))
        self.label_21.setText(_translate("MainWindow", "size"))
        self.path.setText(_translate("MainWindow", "Path"))
        self.format.setItemText(0, _translate("MainWindow", "png"))
        self.format.setItemText(1, _translate("MainWindow", "svg"))
        self.format.setItemText(2, _translate("MainWindow", "pdf"))
        self.format.setItemText(3, _translate("MainWindow", "tif"))
        self.save_box.setText(_translate("MainWindow", "Save"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("MainWindow", "analysis"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())
